@@ -759,7 +759,7 @@ def command_thread():
     parser_config.add_argument('--verify', help='Specify your encryption method', type=str, default="md5")
     parser_config.add_argument('--do-not-use-ssl', help="Use http://", action="store_true", default=False, dest="use_http")
     parser_config.add_argument('--anonymous', help="Anonymous operation", action="store_true", default=False, dest="anonymous")
-    parser_config.add_argument('--l5', help="l5", action="store_true", type=str, default='', dest="l5")
+    parser_config.add_argument('--l5', help="l5", type=str, default='', dest="l5")
     parser_config.set_defaults(func=config)
 
     parser_upload = sub_parser.add_parser("upload", help="Upload file or directory to COS")
